@@ -6,7 +6,7 @@ use warnings;
 use Carp  qw(croak);
 use Date::Simple ();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 my @members = qw(
     FukudaAsuka
@@ -34,10 +34,15 @@ my @members = qw(
     MitsuiAika
     LiChun
     QianLin
-    KanonSuzuki
-    ErinaIkuta
-    MizukiFukumura
-    RihoSayashi
+    SuzukiKanon
+    IkutaErina
+    FukumuraMizuki
+    SayashiRiho
+    IikuboHaruna
+    IshidaAyumi
+    SatohMasaki
+    KudohHaruka
+    OdaSakura
 );
 
 my @date_joined = map { Date::Simple->new($_) } qw(
@@ -50,6 +55,8 @@ my @date_joined = map { Date::Simple->new($_) } qw(
     2005-05-01
     2006-12-10
     2011-01-02
+    2011-09-29
+    2012-09-14
 );
 unshift @date_joined, undef;
 
@@ -247,7 +254,7 @@ Kentaro Kuribayashi E<lt>kentaro@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE (The MIT License)
 
-Copyright (c) 2005 - 2009, Kentaro Kuribayashi
+Copyright (c) 2005 - 2013, Kentaro Kuribayashi
 E<lt>kentaro@cpan.orgE<gt>
 
 Permission is hereby granted, free of charge, to any person obtaining
